Actions, Resources, and Condition Keys for AWS Backup - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Backup.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

# Actions, Resources, and Condition Keys for AWS Backup

AWS Backup (service prefix: `backup`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS Backup
- Resources Defined by AWS Backup
- Condition Keys for AWS Backup

## Actions Defined by AWS Backup

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateBackupPlan | Creates a new backup plan | Write | backupVault* |  |
CreateBackupSelection | Creates a new resource assignment in a backup plan. | Write |  |  |
CreateBackupVault | Creates a new backup vault. | Write | backupVault* |  |
DeleteBackupPlan | Deletes a backup plan. | Write |  |  |
DeleteBackupSelection | Deletes a resource assignment from a backup plan. | Write |  |  |
DeleteBackupVault | Deletes a backup vault. | Write | backupVault* |  |
DeleteBackupVaultAccessPolicy | Deletes backup vault access policy. | Write | backupVault* |  |
DeleteBackupVaultNotifications | Remove notifications from backup vault. | Write | backupVault* |  |
DeleteRecoveryPoint | Deletes a recovery point from a backup vault. | Write | backupVault* |  |
DescribeBackupJob | Describes a backup job | List |  |  |
DescribeBackupVault | Creates a new backup vault with the specified name. | Read | backupVault* |  |
DescribeProtectedResource | Describes a protected resource. | Read |  |  |
DescribeRecoveryPoint | Describes a recovery point. | Read | backupVault* |  |
DescribeRestoreJob | Describes a restore job. | Read | backupVault* |  |
ExportBackupPlanTemplate | Exports a backup plan as a JSON. | Read |  |  |
GetBackupPlan | Gets a backup plan. | Read |  |  |
GetBackupPlanFromJSON | Transforms a JSON to a backup plan. | Read |  |  |
GetBackupPlanFromTemplate | Transforms a template to a backup plan. | Read |  |  |
GetBackupSelection | Gets a backup plan resource assignment. | Read | backupVault* |  |
GetBackupVaultAccessPolicy | Gets backup vault access policy. | Read | backupVault* |  |
GetBackupVaultNotifications | Gets backup vault notifications. | Read | backupVault* |  |
GetRecoveryPointRestoreMetadata | Gets recovery point restore metadata. | Read | backupVault* |  |
GetSupportedResourceTypes | Gets supported resource types. | Read |  |  |
ListBackupJobs | Lists backup jobs. | List |  |  |
ListBackupPlanTemplates | Lists backup plan templates provided by AWS Backup. | List |  |  |
ListBackupPlanVersions | Lists backup plan versions. | List |  |  |
ListBackupPlans | Lists backup plans. | List |  |  |
ListBackupSelections | Lists resource assignments for a specific backup plan. | List |  |  |
ListBackupVaults | Lists backup vaults. | List |  |  |
ListProtectedResources | Lists protected resources by AWS Backup. | List |  |  |
ListRecoveryPointsByBackupVault | Lists recovery points inside a backup vault. | List | backupVault* |  |
ListRecoveryPointsByResource | Lists recovery points for a resource. | List |  |  |
ListRestoreJobs | Lists restore jobs. | List | backupVault* |  |
ListTags | Lists tags for a resource. | List |  |  |
PutBackupVaultAccessPolicy | Adds an access policy to the backup vault. | Write | backupVault* |  |
PutBackupVaultNotifications | Adds an SNS topic to the backup vault. | Write | backupVault* |  |
StartBackupJob | Starts a new backup job. | Write | backupVault* |  |
StartRestoreJob | Starts a new restore job. | Write | backupVault* |  |
StopBackupJob | Stops a backup job. | Write | backupVault* |  |
TagResource | Tags a resource. | Write |  |  |
UntagResource | Untags a resource. | Write |  |  |
UpdateBackupPlan | Updates a backup plan. | Write |  |  |
UpdateRecoveryPointLifecycle | Updates the lifecycle of the recovery point. | Write | backupVault* |  |

## Resources Defined by AWS Backup

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
backupVault | `arn:${Partition}:backup::${Account}:backup-vault:${BackupVaultName}` |

## Condition Keys for AWS Backup

Backup has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference.

On this page:

- Actions Defined by AWS Backup
- Resources Defined by AWS Backup
- Condition Keys for AWS Backup

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more